@@ -80,7 +80,7 @@ ebic.glmm.bsreg <- function(target, dataset, id, wei = NULL, gam = NULL, test =
         
         i <- 2  
         
-        if ( tool[2] > 0 ) {
+        if ( tool[2] != 0 ) {
           
           while ( tool[i - 1] - tool[i ] > 0  &  NCOL(dat) > 0 )  {   
             
