@@ -15,12 +15,6 @@ lmm.bsreg <- function(target, dataset, id, threshold = 0.05, wei = NULL) {
   } else {
     
     tic <- proc.time()
-    #check for NA values in the dataset and replace them with the variable median or the mode
-    if( any(is.na(dataset)) ) {
-      #dataset = as.matrix(dataset);
-      warning("The dataset contains missing values (NA) and they were replaced automatically by the variable (column) median (for numeric) or by the most frequent level (mode) if the variable is factor")
-      dataset <- apply( dataset, 2, function(x){ x[which(is.na(x))] = median(x, na.rm = TRUE) ; return(x) } ) 
-    }
     ###################
     ini <- lme4::lmer( target ~ dataset + (1 | id), REML = FALSE, weights = wei )
     likini <- logLik(ini) 
