@@ -10,7 +10,8 @@ perm.betaregs <- function(target, dataset, wei = NULL, check = FALSE, logged = F
   thres <- threshold * R + 1
 
   if ( ncores <= 1 ) {
-    
+    oop <- options(warn = -1) 
+    on.exit( options(oop) )    
     if ( is.null(wei) ) {
       ly1 <- log(1 - target)     ;    ly <- log(target) - ly1           
       sly1 <- sum(ly1)           ;    sly2 <- sum( log( target ) ) + sly1  
@@ -27,10 +28,8 @@ perm.betaregs <- function(target, dataset, wei = NULL, check = FALSE, logged = F
     pvalue <- dof <- loglik <- numeric(D)   
     
     if ( is.null(wei) ) {
-      
       for (i in 1:D) {
         x <- model.matrix(target ~ ., as.data.frame(dataset[, i]) )
-        options(warn = -1)
         mod1 <- nlm(regbeta, c(iniphi, numeric(dim(x)[2]) ), ly = ly, sly1 = sly1, x = x, n = n, iterlim = 10000 )
         mod2 <- nlm(regbeta, mod1$estimate, ly = ly, sly1 = sly1, x = x, n = n,  iterlim = 10000 )
         loglik[i] <- mod2$minimum 
@@ -45,12 +44,10 @@ perm.betaregs <- function(target, dataset, wei = NULL, check = FALSE, logged = F
         }
         pvalue[i] <- (step + 1) / (R + 1) 
       }
-      
     } else {
-      
+
       for (i in 1:D) {
         x <- model.matrix(target ~ ., as.data.frame(dataset[, i]) )
-        options(warn = -1)
         mod1 <- nlm(regbetawei, c(iniphi, numeric(dim(x)[2]) ), ly = ly, sly1 = sly1, x = x, w = w, iterlim = 10000 )
         mod2 <- nlm(regbetawei, mod1$estimate, ly = ly, sly1 = sly1, x = x, w = w, iterlim = 10000 )
         loglik[i] <-  mod2$minimum 
@@ -65,7 +62,6 @@ perm.betaregs <- function(target, dataset, wei = NULL, check = FALSE, logged = F
         }
         pvalue[i] <- (step + 1) / (R + 1) 
       }
-      
     }
     lik <-  - loglik - sly2
     bic <-  - 2 * lik + dof * log(n) 
@@ -75,17 +71,18 @@ perm.betaregs <- function(target, dataset, wei = NULL, check = FALSE, logged = F
     
     if ( is.null(wei) ) {
       
-      cl <- makePSOCKcluster(ncores)
-      registerDoParallel(cl)
+      cl <- parallel::makePSOCKcluster(ncores)
+      doParallel::registerDoParallel(cl)
       ly1 <- log(1 - target)     ;    ly <- log(target) - ly1           
       sly1 <- sum(ly1)           ;    sly2 <- sum( log( target ) ) + sly1  
       a <- Rfast::beta.mle(target)
       ini <- 2 * a$loglik
       n <- length(target)
       iniphi <- log( sum(a$param) )
-      mod <- foreach( i = 1:D, .combine = rbind, .export = "regbeta" ) %dopar% {
+      oop <- options(warn = -1) 
+      on.exit( options(oop) )
+      mod <- foreach::foreach( i = 1:D, .combine = rbind, .export = "regbeta" ) %dopar% {
         x <- model.matrix(target ~ ., as.data.frame(dataset[, i]) )
-        options(warn = -1)
         mod1 <- nlm(regbeta, c(iniphi, numeric(dim(x)[2]) ), ly = ly, sly1 = sly1, x = x, n = n, iterlim = 10000 )
         mod2 <- nlm(regbeta, mod1$estimate, ly = ly, sly1 = sly1, x = x, n = n, iterlim = 10000 )
         loglik <- mod2$minimum
@@ -101,12 +98,11 @@ perm.betaregs <- function(target, dataset, wei = NULL, check = FALSE, logged = F
         pvalue <- (step + 1) / (R + 1) 
         return( c( loglik, pvalue, dof ) )
       }
-      stopCluster(cl)
-      
+      parallel::stopCluster(cl)
     } else {
       
-      cl <- makePSOCKcluster(ncores)
-      registerDoParallel(cl)
+      cl <- parallel::makePSOCKcluster(ncores)
+      doParallel::registerDoParallel(cl)
       n <- length(target)
       w <- wei / sum(wei)
       ly1 <- w * log(1 - target)     ;    ly <- w * log(target) - ly1
@@ -114,10 +110,10 @@ perm.betaregs <- function(target, dataset, wei = NULL, check = FALSE, logged = F
       a <- betamle.wei(target ,w)
       ini <- 2 * a$loglik
       iniphi <- log( sum( a$param ) )
-      
-      mod <- foreach( i = 1:D, .combine = rbind, .export = "regbetawei" ) %dopar% {
+      oop <- options(warn = -1) 
+      on.exit( options(oop) )      
+      mod <- foreach::foreach( i = 1:D, .combine = rbind, .export = "regbetawei" ) %dopar% {
         x <- model.matrix(target ~ ., as.data.frame(dataset[, i]) )
-        options(warn = -1)
         mod1 <- nlm(regbetawei, c(iniphi, numeric(dim(x)[2]) ), ly = ly, sly1 = sly1, x = x, w = w, iterlim = 10000 )
         mod2 <- nlm(regbetawei, mod1$estimate, ly = ly, sly1 = sly1, x = x, w = w, iterlim = 10000 )
         loglik <- mod2$minimum
@@ -133,7 +129,7 @@ perm.betaregs <- function(target, dataset, wei = NULL, check = FALSE, logged = F
         pvalue <- (step + 1) / (R + 1) 
         return( c( loglik, pvalue, dof ) )
       }
-      stopCluster(cl)
+      parallel::stopCluster(cl)
     }
     
     lik <-  - mod[, 1] - sly2
@@ -144,9 +140,9 @@ perm.betaregs <- function(target, dataset, wei = NULL, check = FALSE, logged = F
   
   if (check) {
     if ( sum(id>0) > 0 ) {
-      stat[id] = 0
-      pvalue[id] = log(1)
-      bic[id] = NA
+      stat[id] <- 0
+      pvalue[id] <- log(1)
+      bic[id] <- NA
     }
   } 
   cbind(stat, log(pvalue), bic)
