@@ -8,9 +8,9 @@ permgSquare = function(target, dataset, xIndex, csIndex, wei = NULL, univariateM
     csIndex2 = sort(csIndex2)
     xcs = c(xIndex,csIndex2)
     key = paste(as.character(xcs) , collapse=" ");
-    if (is.null(stat_hash[[key]]) == FALSE ) {
-      stat = stat_hash[[key]];
-      pvalue = pvalue_hash[[key]];
+    if (is.null(stat_hash[key]) == FALSE ) {
+      stat = stat_hash[key];
+      pvalue = pvalue_hash[key];
       results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
@@ -21,8 +21,8 @@ permgSquare = function(target, dataset, xIndex, csIndex, wei = NULL, univariateM
   if (length(csIndex) == 1)  {
     if (xIndex == csIndex)  {
       if ( hash ) {    #update hash objects
-        stat_hash[[key]] <- 0;     #.set(stat_hash , key , 0)
-        pvalue_hash[[key]] <- 1;     #.set(pvalue_hash , key , 1)
+        stat_hash[key] <- 0;     #.set(stat_hash , key , 0)
+        pvalue_hash[key] <- 1;     #.set(pvalue_hash , key , 1)
       }
       pvalue = log(1)
       stat = 0;
@@ -51,8 +51,8 @@ permgSquare = function(target, dataset, xIndex, csIndex, wei = NULL, univariateM
   }
   
   if ( hash ) {
-    stat_hash[[key]] <- stat;      #.set(stat_hash , key , stat)
-    pvalue_hash[[key]] <- pvalue;     #.set(pvalue_hash , key , pvalue)
+    stat_hash[key] <- stat;      #.set(stat_hash , key , stat)
+    pvalue_hash[key] <- pvalue;     #.set(pvalue_hash , key , pvalue)
   }
   
   results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
