@@ -1,10 +1,6 @@
 ####################
 #### Univariate ridge regression
 ####################
-
-### usage: ridge.reg(target, dataset, lambda, B = 1, newdata = NULL) 
-
-
 ridge.reg <- function(target, dataset, lambda, B = 1, newdata = NULL) {
   ## target is the dependent variable and can be a matrix as well
   ## However we only use it with a univariate target variable
@@ -15,23 +11,19 @@ ridge.reg <- function(target, dataset, lambda, B = 1, newdata = NULL) {
   ## newdata is the new independent variables values 
   ## whose values of y you want to estimate
   ## by default newdata is NULL
-  
   target <- as.vector(target)
   dataset <- as.matrix(dataset)
-  n <- length(target)  ## sample size
-  p <- ncol(dataset)  ## dimensionality of dataset
+  dm <- dim(dataset)
+  n <- dm[1]  ## sample size
+  p <- dm[2]  ## dimensionality of dataset
   my <- sum(target) / n
   yy <- target - my  ## center the dependent variables
-  s <- Rfast::colVars(dataset, std = TRUE) 
-  mx <- as.vector( Rfast::colmeans(dataset) )
-  xx <- t( ( t(dataset) - mx ) / s )
-
-  xtx <- crossprod(xx)
+  xtx <- crossprod(dataset)
   lamip <- lambda * diag(p)
   
   W <- solve( xtx + lamip )
-  betas <- W %*% crossprod(xx, yy) 
-  est <- xx %*% betas + my
+  betas <- W %*% crossprod(dataset, yy) 
+  est <- dataset %*% betas + my
   va <- Rfast::Var(target - est) * (n - 1) / (n - p - 1)
   # vab <- kronecker(va, W %*% xtx %*% W  ) 
   # seb <- as.vector( sqrt( diag(vab) ) )
@@ -42,7 +34,7 @@ ridge.reg <- function(target, dataset, lambda, B = 1, newdata = NULL) {
     be <- matrix(nrow = B, ncol = p )
     for ( i in 1:B) {
        id <- sample(1:n, n, replace = TRUE)
-       yb <- yy[id]     ;     xb <- xx[id, ]
+       yb <- yy[id]     ;     xb <- dataset[id, ]
        be[i, ] <- solve( crossprod(xb) + lamip, crossprod(xb, yb) )
     }
     seb <- Rfast::colVars(be, std = TRUE) ## bootstrap standard errors of betas
@@ -50,28 +42,19 @@ ridge.reg <- function(target, dataset, lambda, B = 1, newdata = NULL) {
   
   be <- as.vector(betas)
   ## seb contains the standard errors of the coefficients
-  
   if ( is.null( colnames(dataset) ) ) {
     names(seb) <- paste("X", 1:p, sep = "")
     names(be) <- paste("X", 1:p, sep = "")
-    
   } else  names(seb) <- names(be) <- colnames(dataset)
-  if ( !is.null(newdata) ) {
-    
+  
+  est <- NULL  
+  if ( !is.null(newdata) ) {  
     newdata <- as.matrix(newdata)
     newdata <- matrix(newdata, ncol = p)
-    newdata <- t( ( t(newdata) - mx ) / s ) ## standardize the independent variables of the new data
-    est <- newdata %*% beta + my 
-  } else est <- est
+    est <- as.vector( newdata %*% beta ) + my 
+  } 
   
-  est <- as.vector(est) 
   list(beta = be, seb = seb, est = est)
-  
 }
 
 
-
-### References
-### Hoerl, A.E. and R.W. Kennard (1970). Ridge regression: Biased estimation for nonorthogonal problems". Technometrics, 12(1):55?67
-### Brown, P. J. (1994). Measurement, Regression and Calibration. Oxford Science Publications.
-
